summaryrefslogtreecommitdiffstats
path: root/lib/CodeGen/CGVTables.h
diff options
context:
space:
mode:
authorTimur Iskhodzhanov <timurrrr@google.com>2013-11-05 15:54:58 +0000
committerTimur Iskhodzhanov <timurrrr@google.com>2013-11-05 15:54:58 +0000
commit5f0db587078b5af32fc9ac41fe4276b80918fd8d (patch)
treeb5b4be2c7ac17eb3ef2c298b54cf0d7bed454748 /lib/CodeGen/CGVTables.h
parenta257e2129c83c06ecd52a5e8eedcdf5aed3f6247 (diff)
Fix vbtable indices when a class shares the vbptr with a non-virtual base
git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@194082 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/CodeGen/CGVTables.h')
-rw-r--r--lib/CodeGen/CGVTables.h14
1 files changed, 8 insertions, 6 deletions
diff --git a/lib/CodeGen/CGVTables.h b/lib/CodeGen/CGVTables.h
index 7c94a07fd9..e8cd55eed8 100644
--- a/lib/CodeGen/CGVTables.h
+++ b/lib/CodeGen/CGVTables.h
@@ -31,10 +31,10 @@ namespace CodeGen {
class CodeGenVTables {
CodeGenModule &CGM;
- // FIXME: Consider moving VTContext and VFTContext into respective CXXABI
- // classes?
- ItaniumVTableContext VTContext;
- OwningPtr<MicrosoftVFTableContext> VFTContext;
+ // FIXME: Consider moving ItaniumVTContext and MicrosoftVTContext into
+ // respective CXXABI classes?
+ ItaniumVTableContext ItaniumVTContext;
+ OwningPtr<MicrosoftVTableContext> MicrosoftVTContext;
/// VTableAddressPointsMapTy - Address points for a single vtable.
typedef llvm::DenseMap<BaseSubobject, uint64_t> VTableAddressPointsMapTy;
@@ -72,9 +72,11 @@ public:
CodeGenVTables(CodeGenModule &CGM);
- ItaniumVTableContext &getVTableContext() { return VTContext; }
+ ItaniumVTableContext &getItaniumVTableContext() { return ItaniumVTContext; }
- MicrosoftVFTableContext &getVFTableContext() { return *VFTContext.get(); }
+ MicrosoftVTableContext &getMicrosoftVTableContext() {
+ return *MicrosoftVTContext.get();
+ }
/// getSubVTTIndex - Return the index of the sub-VTT for the base class of the
/// given record decl.